import Vue from 'vue';
import axios from 'axios';
import router from './router';
import VueSocketIO from 'vue-socket.io';
import VueAxios from 'vue-axios';
import Notifications from '@voerro/vue-notifications'
import VueCompositionAPI from '@vue/composition-api'
import VModal from 'vue-js-modal'
import VueClipboard from 'vue-clipboard2'
import VueFullscreen from 'vue-fullscreen';
import Layout from './components/Layout'

VueClipboard.config.autoSetContainer = true

Vue.use(VueFullscreen);
Vue.component('notifications', Notifications);
Vue.use(VueClipboard)
Vue.use(VueCompositionAPI);
Vue.use(VueAxios, axios);
Vue.use(VModal, {
    dynamicDefaults: {
        draggable: true,
        resizable: true,
        height: "auto",
    },
});

let port = '8443';

Vue.use(new VueSocketIO({
    connection: `${window.location.protocol}//${window.location.hostname}:${port}`
}));

axios.defaults.baseURL = '/';

new Vue({
    data: {
        user: null,
        config: {
            recaptcha_site: null,
            tg_bot: null,
            tg_channel: null,
            vk_support_url: null,
            vk_url: null
        },
        isLoading: true,
        authType: 'login',
    },
    created() {
        this.getUser();
        this.getConfig();
    },
    methods: {
        getUser() {
            this.axios.post('/user/init')
            .then(response => {
                const { data } = response;
                if(data.user) this.user = data.user;
                else {
                    if(location.pathname != '/') this.$router.push({name: 'index'})
                }
            })
        },
        getConfig() {
            this.axios.post('/config/init')
            .then(response => {
                const { data } = response;
                this.config = data;
            })
            .catch(err => {
                notify({
                    theme: 'red',
                    text: 'При инициализации произошла ошибка. Обновите страницу'
                })
            })
        },
        goToBonus() {
            this.$router.push({name: 'bonus'})
        },
        goToRef() {
            this.$router.push({name: 'referral'})
        }
    },
    router,
    render: (h) => h(Layout),
}).$mount('#root');